@@ -1,8 +1,10 @@
 # -*- coding: utf-8 -*-
 
+from typing import Dict, Any
+
 from qtpy import QtCore, QtGui
 
-from prettyqt.utils import bidict
+from prettyqt.utils import bidict, InvalidParamError
 
 
 SHAPES = bidict(
@@ -15,6 +17,9 @@ SHAPES = bidict(
 
 
 class Cursor(QtGui.QCursor):
+    def serialize_fields(self) -> Dict[str, Any]:
+        return dict(shape=self.get_shape(),)
+
     def set_shape(self, shape: str):
         """Set cursor shape.
 
@@ -24,10 +29,10 @@ class Cursor(QtGui.QCursor):
             shape: shape to use
 
         Raises:
-            ValueError: shape does not exist
+            InvalidParamError: shape does not exist
         """
         if shape not in SHAPES:
-            raise ValueError(f"Invalid shape type '{shape}.")
+            raise InvalidParamError(shape, SHAPES)
         self.setShape(SHAPES[shape])
 
     def get_shape(self) -> str:
