@@ -3,7 +3,7 @@
 from qtpy import QtCore, QtGui
 
 from prettyqt import core, gui
-from prettyqt.utils import bidict, colors
+from prettyqt.utils import bidict, colors, InvalidParamError
 
 
 PEN_TYPES = bidict(none=QtCore.Qt.NoPen)
@@ -47,7 +47,7 @@ class Painter(QtGui.QPainter):
 
     def fill_rect(self, rect, color, pattern="solid"):
         if pattern not in PATTERNS:
-            raise ValueError(f"Invalid pattern. Valid values: {PATTERNS.keys()}")
+            raise InvalidParamError(pattern, PATTERNS)
         if isinstance(rect, tuple):
             rect = core.Rect(*rect)
         if isinstance(color, str):
@@ -67,10 +67,10 @@ class Painter(QtGui.QPainter):
             pen_type: pen type to use
 
         Raises:
-            ValueError: pen type does not exist
+            InvalidParamError: pen type does not exist
         """
         if pen_type not in PEN_TYPES:
-            raise ValueError(f"Invalid pen type. Valid values: {PEN_TYPES.keys()}")
+            raise InvalidParamError(pen_type, PEN_TYPES)
         self.setPen(PEN_TYPES[pen_type])
 
     def get_pen(self) -> str:
@@ -95,12 +95,10 @@ class Painter(QtGui.QPainter):
                          "destination_out", "source_atop", "destination_atop",
 
         Raises:
-            ValueError: composition mode does not exist
+            InvalidParamError: composition mode does not exist
         """
         if mode not in COMP_MODES:
-            raise ValueError(
-                "Invalid composition mode." f" Valid values: {COMP_MODES.keys()}"
-            )
+            raise InvalidParamError(mode, COMP_MODES)
         self.setCompositionMode(COMP_MODES[mode])
 
     def get_composition_mode(self) -> str:
