@@ -1,7 +1,5 @@
 # -*- coding: utf-8 -*-
-"""
-@author: Philipp Temminghoff
-"""
+"""Module containing QSciScintilla-related classes."""
 
 from .sciscintilla import SciScintilla
 
