@@ -14,9 +14,7 @@ logger = logging.getLogger(__name__)
 
 
 def qstring_length(text):
-    """
-    Tries to compute what the length of an utf16-encoded QString would be.
-    """
+    """Tries to compute what the length of an utf16-encoded QString would be."""
     utf16_text = text.encode("utf16")
     length = len(utf16_text) // 2
     # Remove Byte order mark.
@@ -27,14 +25,14 @@ def qstring_length(text):
 
 
 def get_tokens_unprocessed(self, text, stack=("root",)):
-    """ Split ``text`` into (tokentype, text) pairs.
+    """Split ``text`` into (tokentype, text) pairs.
 
-        Monkeypatched to store the final stack on the object itself.
+    Monkeypatched to store the final stack on the object itself.
 
-        The `text` parameter this gets passed is only the current line, so to
-        highlight things like multiline strings correctly, we need to retrieve
-        the state from the previous line (this is done in PygmentsHighlighter,
-        below), and use it to continue processing the current line.
+    The `text` parameter this gets passed is only the current line, so to
+    highlight things like multiline strings correctly, we need to retrieve
+    the state from the previous line (this is done in PygmentsHighlighter,
+    below), and use it to continue processing the current line.
     """
     pos = 0
     tokendefs = self._tokens
@@ -95,7 +93,7 @@ RegexLexer.get_tokens_unprocessed = get_tokens_unprocessed
 
 
 class PygmentsHighlighter(gui.SyntaxHighlighter):
-    """ Syntax highlighter that uses Pygments for parsing. """
+    """Syntax highlighter that uses Pygments for parsing."""
 
     # ---------------------------------------------------------------------------
     #  "QSyntaxHighlighter" interface
@@ -114,8 +112,7 @@ class PygmentsHighlighter(gui.SyntaxHighlighter):
             self._lexer = get_lexer_by_name(lexer)
 
     def highlightBlock(self, string):
-        """ Highlight a block of text.
-        """
+        """Highlight a block of text."""
         prev_data = self.currentBlock().previous().userData()
         if prev_data is not None:
             self._lexer._saved_state_stack = prev_data.syntax_stack
@@ -140,16 +137,16 @@ class PygmentsHighlighter(gui.SyntaxHighlighter):
     # ---------------------------------------------------------------------------
 
     def set_style(self, style):
-        """ Sets the style to the specified Pygments style.
-        """
+        """Sets the style to the specified Pygments style."""
         if isinstance(style, str):
             style = get_style_by_name(style)
         self._style = style
         self._clear_caches()
 
     def set_style_sheet(self, stylesheet):
-        """ Sets a CSS stylesheet. The classes in the stylesheet should
-        correspond to those generated by:
+        """Sets a CSS stylesheet.
+
+        The classes in the stylesheet should correspond to those generated by:
 
             pygmentize -S <style> -f html
 
@@ -165,14 +162,12 @@ class PygmentsHighlighter(gui.SyntaxHighlighter):
     # ---------------------------------------------------------------------------
 
     def _clear_caches(self):
-        """ Clear caches for brushes and formats.
-        """
+        """Clear caches for brushes and formats."""
         self._brushes = {}
         self._formats = {}
 
     def _get_format(self, token):
-        """ Returns a QTextCharFormat for token or None.
-        """
+        """Returns a QTextCharFormat for token or None."""
         if token in self._formats:
             return self._formats[token]
 
@@ -185,15 +180,13 @@ class PygmentsHighlighter(gui.SyntaxHighlighter):
         return result
 
     def _get_format_from_document(self, token, document):
-        """ Returns a QTextCharFormat for token by
-        """
+        """Return a QTextCharFormat for token from document."""
         code, html = next(self._formatter._format_lines([(token, "dummy")]))
         self._document.setHtml(html)
         return gui.TextCursor(self._document).charFormat()
 
     def _get_format_from_style(self, token, style):
-        """ Returns a QTextCharFormat for token by reading a Pygments style.
-        """
+        """Return a QTextCharFormat for token by reading a Pygments style."""
         result = gui.TextCharFormat()
         try:
             token_style = style.style_for_token(token)
@@ -221,8 +214,7 @@ class PygmentsHighlighter(gui.SyntaxHighlighter):
         return result
 
     def _get_brush(self, color):
-        """ Returns a brush for the color.
-        """
+        """Return a brush for the color."""
         result = self._brushes.get(color)
         if result is None:
             qcolor = gui.Color(f"#{color[:6]}")
