@@ -4,6 +4,7 @@ from typing import List
 import warnings
 import functools
 import sys
+import operator
 
 
 def string_to_num_array(array: str) -> List[float]:
@@ -11,6 +12,10 @@ def string_to_num_array(array: str) -> List[float]:
     return [int(i) if i.is_integer() else i for i in floats]
 
 
+def merge_flags(flags, mapping):
+    return functools.reduce(operator.ior, [mapping[t] for t in flags])
+
+
 def deprecated(func):
     """A decorator which can be used to mark functions as deprecated.
 
