@@ -5,7 +5,7 @@ from typing import Optional
 from qtpy import QtCore, QtWidgets
 
 from prettyqt import core, gui
-from prettyqt.utils import bidict
+from prettyqt.utils import bidict, InvalidParamError
 
 
 PRIORITIES = bidict(
@@ -21,6 +21,15 @@ CONTEXTS = bidict(
     application=QtCore.Qt.ApplicationShortcut,
 )
 
+ROLES = bidict(
+    none=QtWidgets.QAction.NoRole,
+    text_heuristic=QtWidgets.QAction.TextHeuristicRole,
+    application_specific=QtWidgets.QAction.ApplicationSpecificRole,
+    about_qt=QtWidgets.QAction.AboutQtRole,
+    about=QtWidgets.QAction.AboutRole,
+    preferences=QtWidgets.QAction.PreferencesRole,
+    quit=QtWidgets.QAction.QuitRole,
+)
 
 QtWidgets.QAction.__bases__ = (core.Object,)
 
@@ -33,24 +42,39 @@ class Action(QtWidgets.QAction):
         icon: gui.icon.IconType = None,
         shortcut: Optional[str] = None,
         tooltip: str = "",
+        checkable: bool = False,
+        statustip: str = "",
+        enabled: bool = True,
     ):
         super().__init__(parent)
         self.set_text(text)
         self.set_icon(icon)
         self.set_shortcut(shortcut)
         self.set_tooltip(tooltip)
+        self.set_checkable(checkable)
+        self.set_statustip(statustip)
+        self.set_enabled(enabled)
 
     def serialize_fields(self):
         return dict(
+            auto_repeat=self.autoRepeat(),
             text=self.text(),
             enabled=self.isEnabled(),
+            visible=self.isVisible(),
+            font=gui.Font(self.font()),
             shortcut=self.shortcut(),
-            tooltip=self.toolTip(),
+            tool_tip=self.toolTip(),
             checkable=self.isCheckable(),
             checked=self.isChecked(),
+            icon=gui.Icon(self.icon()) if not self.icon().isNull() else None,
+            icon_text=self.iconText(),
             priority=self.get_priority(),
+            icon_visible=self.isIconVisibleInMenu(),
+            shortcut_visible=self.isShortcutVisibleInContextMenu(),
+            menu_role=self.get_menu_role(),
             shortcut_context=self.get_shortcut_context(),
-            statustip=self.statusTip(),
+            status_tip=self.statusTip(),
+            whats_this=self.whatsThis(),
         )
 
     def __setstate__(self, state):
@@ -58,8 +82,8 @@ class Action(QtWidgets.QAction):
         self.set_text(state.get("text", ""))
         self.set_enabled(state.get("enabled", True))
         self.set_shortcut(state["shortcut"])
-        self.set_tooltip(state.get("tooltip", ""))
-        self.set_statustip(state.get("statustip", ""))
+        self.set_tooltip(state.get("tool_tip", ""))
+        self.set_statustip(state.get("status_tip", ""))
         self.set_checked(state.get("checked", False))
         self.set_priority(state["priority"])
         self.set_shortcut_context(state["shortcut_context"])
@@ -111,10 +135,10 @@ class Action(QtWidgets.QAction):
             priority: priority for the action
 
         Raises:
-            ValueError: priority does not exist
+            InvalidParamError: priority does not exist
         """
         if priority not in PRIORITIES:
-            raise ValueError(f"{priority} not a valid priority.")
+            raise InvalidParamError(priority, PRIORITIES)
         self.setPriority(PRIORITIES[priority])
 
     def get_priority(self) -> str:
@@ -136,10 +160,10 @@ class Action(QtWidgets.QAction):
             context: shortcut context
 
         Raises:
-            ValueError: shortcut context does not exist
+            InvalidParamError: shortcut context does not exist
         """
         if context not in CONTEXTS:
-            raise ValueError(f"{context} not a valid shortcut context.")
+            raise InvalidParamError(context, CONTEXTS)
         self.setShortcutContext(CONTEXTS[context])
 
     def get_shortcut_context(self) -> str:
@@ -152,6 +176,33 @@ class Action(QtWidgets.QAction):
         """
         return CONTEXTS.inv[self.shortcutContext()]
 
+    def set_menu_role(self, role: str):
+        """Set menu role.
+
+        Allowed values are "none", "text_heuristic", "application_specific", "about_qt",
+        "about", "preferences", "quit"
+
+        Args:
+            role: menu role
+
+        Raises:
+            InvalidParamError: menu role does not exist
+        """
+        if role not in ROLES:
+            raise InvalidParamError(role, ROLES)
+        self.setMenuRole(ROLES[role])
+
+    def get_menu_role(self) -> str:
+        """Return menu role.
+
+        Possible values: "none", "text_heuristic", "application_specific", "about_qt",
+        "about", "preferences", "quit"
+
+        Returns:
+            menu role
+        """
+        return ROLES.inv[self.menuRole()]
+
     def show_shortcut_in_contextmenu(self, state: bool = True):
         self.setShortcutVisibleInContextMenu(state)
 
