@@ -6,7 +6,7 @@ from typing import Optional
 from qtpy import QtWidgets
 
 from prettyqt import widgets
-from prettyqt.utils import bidict
+from prettyqt.utils import bidict, InvalidParamError
 
 
 SELECTION_MODES = bidict(
@@ -52,12 +52,12 @@ class CalendarWidget(QtWidgets.QCalendarWidget):
             mode: selection mode to use
 
         Raises:
-            ValueError: mode does not exist
+            InvalidParamError: mode does not exist
         """
         if mode is None:
             mode = "none"
         if mode not in SELECTION_MODES:
-            raise ValueError("Format must be either 'single' or 'None'")
+            raise InvalidParamError(mode, SELECTION_MODES)
         self.setSelectionMode(SELECTION_MODES[mode])
 
     def get_selection_mode(self) -> str:
