@@ -5,25 +5,24 @@ from typing import Iterable, Union, Mapping, Any
 from qtpy import QtCore, QtWidgets
 
 from prettyqt import core, gui, widgets
-from prettyqt.utils import bidict
+from prettyqt.utils import bidict, InvalidParamError
 
 
-box = QtWidgets.QComboBox
 INSERT_POLICIES = bidict(
-    no_insert=box.NoInsert,
-    top=box.InsertAtTop,
-    current=box.InsertAtCurrent,
-    bottom=box.InsertAtBottom,
-    after_current=box.InsertAfterCurrent,
-    before_current=box.InsertBeforeCurrent,
-    alphabetically=box.InsertAlphabetically,
+    no_insert=QtWidgets.QComboBox.NoInsert,
+    top=QtWidgets.QComboBox.InsertAtTop,
+    current=QtWidgets.QComboBox.InsertAtCurrent,
+    bottom=QtWidgets.QComboBox.InsertAtBottom,
+    after_current=QtWidgets.QComboBox.InsertAfterCurrent,
+    before_current=QtWidgets.QComboBox.InsertBeforeCurrent,
+    alphabetically=QtWidgets.QComboBox.InsertAlphabetically,
 )
 
 SIZE_POLICIES = bidict(
-    content=box.AdjustToContents,
-    first_show=box.AdjustToContentsOnFirstShow,
-    min_length=box.AdjustToMinimumContentsLength,
-    min_length_with_icon=box.AdjustToMinimumContentsLengthWithIcon,
+    content=QtWidgets.QComboBox.AdjustToContents,
+    first_show=QtWidgets.QComboBox.AdjustToContentsOnFirstShow,
+    min_length=QtWidgets.QComboBox.AdjustToMinimumContentsLength,
+    min_length_with_icon=QtWidgets.QComboBox.AdjustToMinimumContentsLengthWithIcon,
 )
 
 
@@ -52,7 +51,12 @@ class ComboBox(QtWidgets.QComboBox):
             editable=self.isEditable(),
             max_count=self.maxCount(),
             has_frame=self.hasFrame(),
+            icon_size=self.iconSize(),
+            insert_policy=self.insertPolicy(),
+            model_column=self.modelColumn(),
+            placeholder_text=self.placeholderText(),
             max_visible_items=self.maxVisibleItems(),
+            size_adjust_policy=self.get_size_adjust_policy(),
             duplicates_enabled=self.duplicatesEnabled(),
             min_contents_length=self.minimumContentsLength(),
             items=items,
@@ -65,8 +69,8 @@ class ComboBox(QtWidgets.QComboBox):
         self.set_id(state.get("object_name", ""))
         self.setCurrentIndex(state["index"])
         self.setEnabled(state.get("enabled", True))
-        self.setToolTip(state.get("tooltip", ""))
-        self.setStatusTip(state.get("statustip", ""))
+        self.setToolTip(state.get("tool_tip", ""))
+        self.setStatusTip(state.get("status_tip", ""))
         self.setEditable(state["editable"])
         self.setMaxCount(state["max_count"])
         self.setMaxVisibleItems(state["max_visible_items"])
@@ -114,10 +118,10 @@ class ComboBox(QtWidgets.QComboBox):
             policy: insert policy to use
 
         Raises:
-            ValueError: invalid insert policy
+            InvalidParamError: invalid insert policy
         """
         if policy not in INSERT_POLICIES:
-            raise ValueError("Policy not available")
+            raise InvalidParamError(policy, INSERT_POLICIES)
         policy = INSERT_POLICIES.get(policy)
         self.setInsertPolicy(policy)
 
@@ -141,10 +145,10 @@ class ComboBox(QtWidgets.QComboBox):
             policy: size adjust policy to use
 
         Raises:
-            ValueError: invalid size adjust policy
+            InvalidParamError: invalid size adjust policy
         """
         if policy not in SIZE_POLICIES:
-            raise ValueError("Policy not available")
+            raise InvalidParamError(policy, SIZE_POLICIES)
         policy = SIZE_POLICIES.get(policy)
         self.setSizeAdjustPolicy(policy)
 
