@@ -43,8 +43,8 @@ class DoubleSpinBox(QtWidgets.QDoubleSpinBox):
         self.set_range(*state["range"])
         self.setValue(state["value"])
         self.setEnabled(state.get("enabled", True))
-        self.setToolTip(state.get("tooltip", ""))
-        self.setStatusTip(state.get("statustip", ""))
+        self.setToolTip(state.get("tool_tip", ""))
+        self.setStatusTip(state.get("status_tip", ""))
         self.setPrefix(state["prefix"])
         self.setSuffix(state["suffix"])
         self.setDecimals(state["decimals"])
