@@ -1,7 +1,5 @@
 # -*- coding: utf-8 -*-
 
-import functools
-import operator
 import pathlib
 
 from typing import List, Optional, Union
@@ -9,7 +7,7 @@ from typing import List, Optional, Union
 from qtpy import QtCore, QtWidgets
 
 from prettyqt import gui, widgets
-from prettyqt.utils import bidict, colors
+from prettyqt.utils import bidict, colors, InvalidParamError, helpers
 
 
 H_ALIGNMENTS = bidict(
@@ -115,10 +113,10 @@ class Label(QtWidgets.QLabel):
             text_format: text format to use
 
         Raises:
-            ValueError: text format does not exist
+            InvalidParamError: text format does not exist
         """
         if text_format not in TEXT_FORMATS:
-            raise ValueError("Invalid text format")
+            raise InvalidParamError(text_format, TEXT_FORMATS)
         self.setTextFormat(TEXT_FORMATS[text_format])
         return self
 
@@ -141,12 +139,12 @@ class Label(QtWidgets.QLabel):
             types: text interaction mode to use
 
         Raises:
-            ValueError: text interaction mode does not exist
+            InvalidParamError: text interaction mode does not exist
         """
         for item in types:
             if item not in TEXT_INTERACTION:
-                raise ValueError("Invalid text interaction mode")
-        flags = functools.reduce(operator.ior, [TEXT_INTERACTION[t] for t in types])
+                raise InvalidParamError(item, TEXT_INTERACTION)
+        flags = helpers.merge_flags(types, TEXT_INTERACTION)
         self.setTextInteractionFlags(flags)
         return self
 
@@ -192,10 +190,10 @@ class Label(QtWidgets.QLabel):
             weight: font weight
 
         Raises:
-            ValueError: invalid font weight
+            InvalidParamError: invalid font weight
         """
         if weight not in WEIGHTS:
-            raise ValueError(f"Invalid weight '{weight}'")
+            raise InvalidParamError(weight, WEIGHTS)
         font = self.font()
         font.setWeight(WEIGHTS[weight])
         self.setFont(font)
