@@ -5,7 +5,7 @@ from typing import Optional, Union
 from qtpy import QtCore, QtWidgets
 
 from prettyqt import core, widgets
-from prettyqt.utils import bidict
+from prettyqt.utils import bidict, InvalidParamError
 
 
 TICK_POSITIONS = bidict(
@@ -44,8 +44,8 @@ class Slider(QtWidgets.QSlider):
         self.__init__()
         self.set_range(*state["range"])
         self.set_value(state["value"])
-        self.setToolTip(state.get("tooltip", ""))
-        self.setStatusTip(state.get("statustip", ""))
+        self.setToolTip(state.get("tool_tip", ""))
+        self.setStatusTip(state.get("status_tip", ""))
         self.setEnabled(state.get("enabled", True))
         self.setSingleStep(state["single_step"])
         self.setPageStep(state["page_step"])
@@ -70,7 +70,7 @@ class Slider(QtWidgets.QSlider):
         elif position == "right":
             position = "below"
         elif position not in TICK_POSITIONS:
-            raise ValueError(f"{position} not a valid tick position.")
+            raise InvalidParamError(position, TICK_POSITIONS)
         self.setTickPosition(TICK_POSITIONS[position])
 
     def get_tick_position(self) -> str:
